@@ -16,7 +16,7 @@ use Array::Utils qw/intersect/;
 
 extends 'App::VTide::Command';
 
-our $VERSION = version->new('0.0.2');
+our $VERSION = version->new('0.0.3');
 our $NAME    = 'conf';
 our $OPTIONS = [
     'env|e',
@@ -60,7 +60,7 @@ sub run {
         for my $file (@files) {
             my $data = Dump( $data->{$file} );
             $data =~ s/^---//xms;
-            print "\n", $file, $data, "\n";
+            print $file, $data, "\n";
         }
     }
     else {
@@ -137,7 +137,7 @@ App::VTide::Command::Conf - Show the current VTide configuration and environment
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command::Conf version 0.0.2
+This documentation refers to App::VTide::Command::Conf version 0.0.3
 
 =head1 SYNOPSIS
 
