@@ -14,7 +14,7 @@ use English qw/ -no_match_vars /;
 
 extends 'App::VTide::Command::Run';
 
-our $VERSION = version->new('0.0.2');
+our $VERSION = version->new('0.0.3');
 our $NAME    = 'edit';
 our $OPTIONS = [
     'test|T!',
@@ -54,6 +54,15 @@ sub auto_complete {
     my $env = $self->options->files->[-1];
     my @files = sort keys %{ $self->config->get->{editor}{files} };
 
+    eval {
+        my $helper = $self->config->get->{editor}{helper_autocomplete};
+        if ($helper) {
+            $helper = eval $helper;  ## no critic
+            push @files, $helper->();
+        }
+        1;
+    } or do { warn $@ };
+
     print join ' ', grep { $env ne 'edit' ? /^$env/xms : 1 } @files;
 
     return;
@@ -69,7 +78,7 @@ App::VTide::Command::Edit - Run an edit command (like Run but without a terminal
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command::Edit version 0.0.2
+This documentation refers to App::VTide::Command::Edit version 0.0.3
 
 =head1 SYNOPSIS
 
