@@ -18,7 +18,7 @@ use File::chdir;
 
 extends 'App::VTide::Command';
 
-our $VERSION = version->new('0.0.2');
+our $VERSION = version->new('0.0.3');
 our $NAME    = 'run';
 our $OPTIONS = [
     'name|n=s',
@@ -208,19 +208,31 @@ sub command {
         and Term::Title::set_titlebar($params->{title} || $globs[0]);
 
     my $helper = $self->config->get->{editor}{helper};
-    if ($helper) {
-        $helper = eval $helper;  ## no critic
-    }
+    eval {
+        if ($helper) {
+            $helper = eval $helper;  ## no critic
+        }
+        1;
+    } or do { warn $@ };
 
     my $groups = $self->config->get->{editor}{files};
+    GLOB:
     while ( my $glob = shift @globs ) {
         if ( $groups->{$glob} ) {
             push @globs, @{ $groups->{$glob} };
-            next;
+            next GLOB;
         }
-        elsif ( my @g = $helper->($self, $glob) ) {
-            push @globs, @g;
-            next;
+        elsif ( $helper ) {
+            my @g;
+            eval {
+                @g = $helper->($self, $glob);
+                1;
+            } or do { warn $@ };
+
+            if (@g) {
+                push @globs, @g;
+                next GLOB;
+            }
         }
 
         push @files, $self->_dglob($glob);
@@ -293,7 +305,7 @@ App::VTide::Command::Run - Run a terminal command
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command::Run version 0.0.2
+This documentation refers to App::VTide::Command::Run version 0.0.3
 
 =head1 SYNOPSIS
 
